@@ -1,9 +1,9 @@
-from datetime import datetime
+from django.utils.timezone import now
 
 
 class DateFunctions:
     def get_functions(self):
         return {
-            "now": lambda **kwargs: datetime.now(),
+            "now": lambda **kwargs: now(),
             "date": lambda year, month, day, **kwargs: datetime(year, month, day),
         }
